package com.ruoyi.model.service;

import java.util.List;
import com.ruoyi.model.domain.AppletComment;

/**
 * 用户评价Service接口
 * 
 * @author ruoyi
 * @date 2025-03-28
 */
public interface IAppletCommentService 
{
    /**
     * 查询用户评价
     * 
     * @param id 用户评价主键
     * @return 用户评价
     */
    public AppletComment selectAppletCommentById(Long id);

    /**
     * 查询用户评价列表
     * 
     * @param appletComment 用户评价
     * @return 用户评价集合
     */
    public List<AppletComment> selectAppletCommentList(AppletComment appletComment);

    /**
     * 新增用户评价
     * 
     * @param appletComment 用户评价
     * @return 结果
     */
    public int insertAppletComment(AppletComment appletComment);

    /**
     * 修改用户评价
     * 
     * @param appletComment 用户评价
     * @return 结果
     */
    public int updateAppletComment(AppletComment appletComment);

    /**
     * 批量删除用户评价
     * 
     * @param ids 需要删除的用户评价主键集合
     * @return 结果
     */
    public int deleteAppletCommentByIds(Long[] ids);

    /**
     * 删除用户评价信息
     * 
     * @param id 用户评价主键
     * @return 结果
     */
    public int deleteAppletCommentById(Long id);
}
