package com.ruoyi.model.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.AppletComment;
import com.ruoyi.model.service.IAppletCommentService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 用户评价Controller
 * 
 * @author ruoyi
 * @date 2025-03-28
 */
@RestController
@RequestMapping("/model/AppletComment")
public class AppletCommentController extends BaseController
{
    @Autowired
    private IAppletCommentService appletCommentService;

    /**
     * 查询用户评价列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletComment:list')")
    @GetMapping("/list")
    public TableDataInfo list(AppletComment appletComment)
    {
        startPage();
        List<AppletComment> list = appletCommentService.selectAppletCommentList(appletComment);
        return getDataTable(list);
    }

    /**
     * 导出用户评价列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppletComment:export')")
    @Log(title = "用户评价", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppletComment appletComment) throws IOException {
        List<AppletComment> list = appletCommentService.selectAppletCommentList(appletComment);
        ExcelUtil<AppletComment> util = new ExcelUtil<AppletComment>(AppletComment.class);
        util.exportExcel(response, list, "用户评价数据");
    }

    /**
     * 获取用户评价详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppletComment:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(appletCommentService.selectAppletCommentById(id));
    }

    /**
     * 新增用户评价
     */
    @PreAuthorize("@ss.hasPermi('model:AppletComment:add')")
    @Log(title = "用户评价", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppletComment appletComment)
    {
        return toAjax(appletCommentService.insertAppletComment(appletComment));
    }

    /**
     * 修改用户评价
     */
    @PreAuthorize("@ss.hasPermi('model:AppletComment:edit')")
    @Log(title = "用户评价", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppletComment appletComment)
    {
        return toAjax(appletCommentService.updateAppletComment(appletComment));
    }

    /**
     * 删除用户评价
     */
    @PreAuthorize("@ss.hasPermi('model:AppletComment:remove')")
    @Log(title = "用户评价", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(appletCommentService.deleteAppletCommentByIds(ids));
    }
}
